@@ -1,5 +1,5 @@
 package ETL::Yertl::Command::yts;
-our $VERSION = '0.033';
+our $VERSION = '0.034';
 # ABSTRACT: Read/Write time series data
 
 #pod =head1 SYNOPSIS
@@ -15,6 +15,7 @@ our $VERSION = '0.033';
 use ETL::Yertl;
 use ETL::Yertl::Util qw( load_module );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through );
+use IO::Interactive qw( is_interactive );
 
 sub main {
     my $class = shift;
@@ -44,7 +45,7 @@ sub main {
     my $db = load_module( adapter => $db_type )->new( $db_spec );
 
     # Write metrics
-    if ( !-t STDIN && !-z *STDIN ) {
+    if ( !is_interactive( \*STDIN ) ) {
         if ( $opt{short} ) {
             die "Must give a metric\n" unless $metric;
         }
@@ -116,7 +117,7 @@ ETL::Yertl::Command::yts - Read/Write time series data
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
