@@ -1,33 +1,17 @@
 package ETL::Yertl::Format::csv;
-our $VERSION = '0.033';
+our $VERSION = '0.034';
 # ABSTRACT: CSV read/write support for Yertl
 
-use ETL::Yertl 'Class';
+use ETL::Yertl;
+use base 'ETL::Yertl::Format';
 use Module::Runtime qw( use_module );
 use List::Util qw( pairs pairkeys pairfirst );
 
-#pod =attr input
-#pod
-#pod The filehandle to read from for input.
-#pod
-#pod =cut
-
-has input => (
-    is => 'ro',
-    isa => FileHandle,
-);
-
-#pod =attr delimiter
-#pod
-#pod The delimited to use. Defaults to C<,>. Other common values include C<:>.
-#pod
-#pod =cut
-
-has delimiter => (
-    is => 'ro',
-    isa => Str,
-    default => ',',
-);
+sub new {
+    my ( $class, %args ) = @_;
+    $args{delimiter} ||= ',';
+    return $class->SUPER::new( %args );
+}
 
 #pod =attr format_module
 #pod
@@ -49,56 +33,41 @@ our @FORMAT_MODULES = (
     'Text::CSV' => 0,
 );
 
-has format_module => (
-    is => 'rw',
-    isa => sub {
-        my ( $format_module ) = @_;
-        die "format_module must be one of: " . join( " ", pairkeys @FORMAT_MODULES ) . "\n"
-            unless pairfirst { $a eq $format_module } @FORMAT_MODULES;
+sub format_module {
+    my ( $self ) = @_;
+    return $self->{_format_module} if $self->{_format_module};
+    for my $format_module ( pairs @FORMAT_MODULES ) {
         eval {
-            use_module( $format_module );
+            # Prototypes on use_module() make @$format_module not work correctly
+            use_module( $format_module->[0], $format_module->[1] );
         };
-        if ( $@ ) {
-            die "Could not load format module '$format_module': $@";
+        if ( !$@ ) {
+            return $format_module->[0];
         }
-    },
-    lazy => 1,
-    default => sub {
-        for my $format_module ( pairs @FORMAT_MODULES ) {
-            eval {
-                # Prototypes on use_module() make @$format_module not work correctly
-                use_module( $format_module->[0], $format_module->[1] );
-            };
-            if ( !$@ ) {
-                return $format_module->[0];
-            }
-        }
-        die "Could not load a formatter for CSV. Please install one of the following modules:\n"
-            . join( "",
-                map { sprintf "\t%s (%s)", $_->[0], $_->[1] ? "version $_->[1]" : "Any version" }
-                pairs @FORMAT_MODULES
-            )
-            . "\n";
-    },
-);
+    }
+    die "Could not load a formatter for CSV. Please install one of the following modules:\n"
+        . join( "",
+            map { sprintf "\t%s (%s)", $_->[0], $_->[1] ? "version $_->[1]" : "Any version" }
+            pairs @FORMAT_MODULES
+        )
+        . "\n";
+}
 
-has _field_names => (
-    is => 'rw',
-    isa => ArrayRef[Str],
-    default => sub { [] },
-);
+sub _field_names {
+    my ( $self, $new_names ) = @_;
+    if ( $new_names ) {
+        $self->{_field_names} = $new_names;
+    }
+    return $self->{_field_names} || [];
+}
 
-has _csv => (
-    is => 'ro',
-    lazy => 1,
-    default => sub {
-        my ( $self ) = @_;
-        $self->format_module->new({
-            binary => 1, eol => $\,
-            sep_char => $self->delimiter,
-        });
-    },
-);
+sub _csv {
+    my ( $self ) = @_;
+    return $self->{_csv} ||= $self->format_module->new({
+        binary => 1, eol => $\,
+        sep_char => $self->{delimiter},
+    });
+}
 
 #pod =method write( DOCUMENTS )
 #pod
@@ -135,7 +104,7 @@ sub write {
 
 sub read {
     my ( $self ) = @_;
-    my $fh = $self->input || die "No input filehandle";
+    my $fh = $self->{input} || die "No input filehandle";
     my $csv = $self->_csv;
     my @names = @{ $self->_field_names };
 
@@ -164,18 +133,10 @@ ETL::Yertl::Format::csv - CSV read/write support for Yertl
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 ATTRIBUTES
 
-=head2 input
-
-The filehandle to read from for input.
-
-=head2 delimiter
-
-The delimited to use. Defaults to C<,>. Other common values include C<:>.
-
 =head2 format_module
 
 The module being used for this format. Possible modules, in order of importance:
